# retnet-torch
Strongly typed implementation of the Paper "Retentive Network: A Successor to Transformer for Large Language Models" in Pytorch. https://arxiv.org/pdf/2307.08621.pdf

WORK IN PROGRESS BETTER README SOON
